@@ -1,6 +1,4 @@
 /*
- *  Copyright (c) 2006 Stephan Arts <stephan@xfce.org>
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -35,8 +33,8 @@ gboolean lsq_tempfs_make_dir(LSQArchive *archive, const gchar *path, gint mode);
 gboolean lsq_tempfs_chmod(LSQArchive *archive, const gchar *path, gint mode);
 
 gboolean
-lsq_tempfs_monitor_file(LSQArchive *archive, const gchar *path);
+lsq_tempfs_monitor_file(LSQArchive *archive, const gchar *path) G_GNUC_INTERNAL;
 
 gboolean
-lsq_tempfs_changed_file(LSQArchive *archive, const gchar *path);
+lsq_tempfs_changed_file(LSQArchive *archive, const gchar *path) G_GNUC_INTERNAL;
 
