@@ -35,7 +35,6 @@
 #define SQ_BSD
 #endif
 
-#define LSQ_ARCHIVE_TEMP_FILE "gnu_tar_temp_file"
 
 static void
 lsq_command_builder_gnu_tar_class_init(LSQCommandBuilderGnuTarClass *);
@@ -238,7 +237,8 @@ lsq_command_builder_gnu_tar_build_add(LSQCommandBuilder *builder, LSQArchive *ar
 										 compress_skeleton,
 										 NULL,
 										 NULL,
-										 tmp_file);
+										 NULL);
+		g_object_set_data(G_OBJECT(compress), LSQ_ARCHIVE_TEMP_FILE, tmp_file);
 
 		if(!lsq_spawn_command_set_parse_func(LSQ_SPAWN_COMMAND(compress), 1, lsq_command_builder_gnu_tar_compress_parse_output, NULL))
 		{
@@ -286,6 +286,8 @@ lsq_command_builder_gnu_tar_build_add(LSQCommandBuilder *builder, LSQArchive *ar
 	                                                 files,
 	                                                 options,
                                                      tmp_file);
+	if(tmp_file)
+		g_object_set_data(G_OBJECT(spawn), LSQ_ARCHIVE_TEMP_FILE, tmp_file);
 	add_macro = lsq_macro_command_new(archive);
 	if(decompress)
 	{
@@ -340,7 +342,8 @@ lsq_command_builder_gnu_tar_build_remove(LSQCommandBuilder *builder, LSQArchive
 #endif
 	                                                 files,
 	                                                 options,
-                                                     tmp_file);
+                                                     NULL);
+	g_object_set_data(G_OBJECT(spawn), LSQ_ARCHIVE_TEMP_FILE, tmp_file);
 
 	if(decompress_skeleton)
 	{
@@ -359,6 +362,8 @@ lsq_command_builder_gnu_tar_build_remove(LSQCommandBuilder *builder, LSQArchive
 		                                                    NULL,
 		                                                    NULL,
 		                                                    tmp_file);
+		g_object_set_data(G_OBJECT(compress), LSQ_ARCHIVE_TEMP_FILE, tmp_file);
+
 		remove_macro = lsq_macro_command_new(archive);
 		lsq_macro_command_append(LSQ_MACRO_COMMAND(remove_macro), decompress);
 		g_object_unref(decompress);
