@@ -17,6 +17,10 @@
 #ifndef __LIBSQUEEZE_H__
 #define __LIBSQUEEZE_H__
 
+#ifndef LIBSQUEEZE_API_SUBJECT_TO_CHANGE
+#error "Please define LIBSQUEEZE_API_SUBJECT_TO_CHANGE to acknowledge that you understand that libsqueeze has not reached 1.0 and is subject to api churn."
+#endif
+
 #include <libsqueeze/libsqueeze-archive.h>
 #include <libsqueeze/libsqueeze-vfs-mime.h>
 #include <libsqueeze/libsqueeze-view.h>
