@@ -56,6 +56,7 @@
 #include "notebook.h"
 #include "application.h"
 #include "main_window.h"
+#include "throbber.h"
 
 #include "new_dialog.h"
 #include "extract_dialog.h"
@@ -89,9 +90,11 @@ static void cb_sq_main_add_to_archive(GtkWidget *widget, gpointer userdata);
 static void cb_sq_main_remove_from_archive(GtkWidget *widget, gpointer userdata);
 static void cb_sq_main_close_archive(GtkWidget *widget, gpointer userdata);
 static void cb_sq_main_stop_archive(GtkWidget *widget, gpointer userdata);
+static void cb_sq_main_refresh_archive(GtkWidget *widget, gpointer userdata);
 
 static void cb_sq_main_close_window(GtkWidget *widget, gpointer userdata);
 
+static void cb_sq_main_window_archive_command_terminated(LSQArchive *archive, GError *error, gpointer userdata);
 /*static void cb_sq_main_properties(GtkWidget *widget, gpointer userdata);*/
 /*static void cb_sq_main_preferences(GtkWidget *widget, gpointer userdata);*/
 
@@ -102,9 +105,8 @@ cb_sq_main_window_notebook_page_switched(SQNotebook *, GtkNotebookPage *, guint,
 static void
 cb_sq_main_window_notebook_page_removed(SQNotebook *, gpointer);
 static void
-cb_sq_main_window_notebook_file_activated(SQNotebook *, gchar *, gpointer);
-static void
-cb_sq_main_window_notebook_status_changed(SQNotebook *, LSQArchive *, gpointer);
+cb_sq_main_window_notebook_file_activated(SQNotebook *, LSQArchiveIter *, gpointer);
+ static void cb_sq_main_window_notebook_state_changed(SQNotebook *, LSQArchive *, gpointer);
 
 static void
 sq_main_window_set_navigation(SQMainWindow *window);
@@ -257,9 +259,6 @@ sq_main_window_init(SQMainWindow *window)
 	const gchar   *nav_bar;
 	GSList        *list, *iter;
 	gboolean up_dir = TRUE;
-	gboolean show_icons = TRUE;
-	gboolean sort_case = TRUE;
-	gboolean sort_folders = TRUE;
 	gboolean use_tabs = TRUE;
 	gboolean show_menubar = TRUE;
 
@@ -329,9 +328,27 @@ sq_main_window_init(SQMainWindow *window)
 		gtk_widget_set_sensitive(window->menubar.menu_item_remove, FALSE);
 		gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_remove);
 
+		window->menubar.menu_item_refresh = g_object_ref(gtk_image_menu_item_new_from_stock(GTK_STOCK_REFRESH, window->accel_group));
+		gtk_widget_set_sensitive(window->menubar.menu_item_refresh, FALSE);
+		gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_refresh);
+
 		g_signal_connect(G_OBJECT(window->menubar.menu_item_add), "activate", G_CALLBACK(cb_sq_main_add_to_archive), window);
 		g_signal_connect(G_OBJECT(window->menubar.menu_item_extract), "activate", G_CALLBACK(cb_sq_main_extract_archive), window);
 		g_signal_connect(G_OBJECT(window->menubar.menu_item_remove), "activate", G_CALLBACK(cb_sq_main_remove_from_archive), window);
+		g_signal_connect(G_OBJECT(window->menubar.menu_item_refresh), "activate", G_CALLBACK(cb_sq_main_refresh_archive), window);
+
+		gtk_widget_add_accelerator (window->menubar.menu_item_refresh,
+		                            "activate",
+		                            window->accel_group,
+		                            GDK_F5,
+		                            0,
+		                            GTK_ACCEL_LOCKED | GTK_ACCEL_MASK);
+		gtk_widget_add_accelerator (window->menubar.menu_item_refresh,
+		                            "activate",
+		                            window->accel_group,
+		                            GDK_r,
+		                            GDK_CONTROL_MASK,
+		                            GTK_ACCEL_LOCKED | GTK_ACCEL_MASK);
 
 		/* View menu */
 		window->menubar.menu_item_view = gtk_menu_item_new_with_mnemonic(_("_View"));
@@ -371,6 +388,17 @@ sq_main_window_init(SQMainWindow *window)
 		gtk_menu_bar_append(GTK_MENU_BAR(window->menu_bar), window->menubar.menu_item_action);
 		gtk_menu_bar_append(GTK_MENU_BAR(window->menu_bar), window->menubar.menu_item_view);
 		gtk_menu_bar_append(GTK_MENU_BAR(window->menu_bar), window->menubar.menu_item_help);
+  
+		GtkWidget *item = gtk_menu_item_new ();
+		gtk_widget_set_sensitive (item, FALSE);
+		gtk_menu_item_set_right_justified (GTK_MENU_ITEM (item), TRUE);
+		gtk_menu_shell_append (GTK_MENU_SHELL (window->menu_bar), item);
+		gtk_widget_show (item);
+
+		window->throbber = sq_throbber_new ();
+		gtk_container_add (GTK_CONTAINER (item), window->throbber);
+		gtk_widget_show (window->throbber);
+
 	}
 
 	show_toolbar = sq_settings_read_bool_entry(window->settings, "ToolBar", TRUE);
@@ -449,21 +477,24 @@ sq_main_window_init(SQMainWindow *window)
 
 	g_object_notify(G_OBJECT(window), "navigation-style");
 
-	show_icons = sq_settings_read_bool_entry(window->settings, "ShowIcons", TRUE);
-	sort_case = sq_settings_read_bool_entry(window->settings, "SortCaseSensitive", TRUE);
-	sort_folders = sq_settings_read_bool_entry(window->settings, "SortFoldersFirst", TRUE);
 	use_tabs = sq_settings_read_bool_entry(window->settings, "UseTabs", TRUE);
 
 /* main view */
 	window->notebook = sq_notebook_new(window->navigationbar, use_tabs, window->accel_group);
+	g_signal_connect(G_OBJECT(window->notebook), "archive-state-changed", G_CALLBACK(cb_sq_main_window_notebook_state_changed), window);
 	g_signal_connect(G_OBJECT(window->notebook), "switch-page", G_CALLBACK(cb_sq_main_window_notebook_page_switched), window);
 	g_signal_connect(G_OBJECT(window->notebook), "archive-removed", G_CALLBACK(cb_sq_main_window_notebook_page_removed), window);
 	g_signal_connect(G_OBJECT(window->notebook), "file-activated", G_CALLBACK(cb_sq_main_window_notebook_file_activated), window);
-	g_signal_connect(G_OBJECT(window->notebook), "active-archive-status-changed", G_CALLBACK(cb_sq_main_window_notebook_status_changed), window);
 
 /* menu item */
 	if(show_menubar)
 	{
+		list = sq_widget_factory_create_property_menu(window->widget_factory, G_OBJECT(window->notebook), "show-full-path");
+		for(iter = list; iter; iter = iter->next)
+		{
+			gtk_container_add(GTK_CONTAINER(window->menubar.menu_view), iter->data);
+			gtk_widget_show(iter->data);
+		}
 		list = sq_widget_factory_create_property_menu(window->widget_factory, G_OBJECT(window->notebook), "show-icons");
 		for(iter = list; iter; iter = iter->next)
 		{
@@ -591,42 +622,8 @@ sq_main_window_find_image(gchar *filename, GtkIconSize size)
 }
 
 static void
-sq_main_window_new_action_menu(SQMainWindow *window, LSQArchiveSupport *support, LSQArchive *archive)
+sq_main_window_new_action_menu(SQMainWindow *window, LSQArchive *archive)
 {
-	if(!window->menu_bar)
-		return;
-
-	GSList *iter, *list;
-
-	gtk_container_remove(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_add);
-	gtk_container_remove(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_extract);
-	gtk_container_remove(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_remove);
-
-	window->menubar.menu_action = gtk_menu_new();
-	gtk_menu_item_set_submenu(GTK_MENU_ITEM(window->menubar.menu_item_action), window->menubar.menu_action);
-
-	gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_add);
-	gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_extract);
-	gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), window->menubar.menu_item_remove);
-
-	if(support)
-	{
-		iter = list = sq_widget_factory_create_action_menu(window->widget_factory, support, archive);
-		if(list)
-		{
-			gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), gtk_separator_menu_item_new());
-
-			do
-			{
-				gtk_container_add(GTK_CONTAINER(window->menubar.menu_action), iter->data);
-			}
-			while((iter = iter->next));
-
-			g_slist_free(list);
-		}
-	}
-
-	gtk_widget_show_all(window->menubar.menu_action);
 }
 
 static void
@@ -636,7 +633,6 @@ cb_sq_main_new_archive(GtkWidget *widget, gpointer userdata)
 	gchar *archive_path = NULL;
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 	LSQArchive *archive = NULL;
-	LSQArchiveSupport *support = NULL;
 	gint result = 0;
 
 	result = gtk_dialog_run (GTK_DIALOG (dialog) );
@@ -651,8 +647,20 @@ cb_sq_main_new_archive(GtkWidget *widget, gpointer userdata)
 		
 		if(!lsq_new_archive(archive_path, TRUE, NULL, &archive))
 		{
-			support = lsq_get_support_for_mime(archive->mime_info);
-			sq_notebook_add_archive(SQ_NOTEBOOK(window->notebook), archive, support, TRUE);
+			sq_notebook_add_archive(SQ_NOTEBOOK(window->notebook), archive, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_add, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_extract, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_remove, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, TRUE);
+
+			if(window->tool_bar)
+			{
+				gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_add), TRUE);
+				gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_extract), TRUE);
+				gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_remove), TRUE);
+
+				gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_stop), FALSE);
+			}
 		}
 		else
 		{
@@ -679,18 +687,43 @@ cb_sq_main_open_archive(GtkWidget *widget, gpointer userdata)
 	
 	if(mod_type & GDK_SHIFT_MASK)
 		dialog = gtk_file_chooser_dialog_new(_("Open archive in new window"), 
-																			 GTK_WINDOW(window),
-																			 GTK_FILE_CHOOSER_ACTION_OPEN,
-																			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-																			 GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
+		                                     GTK_WINDOW(window),
+		                                     GTK_FILE_CHOOSER_ACTION_OPEN,
+		                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                                     GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
 	else
 		dialog = gtk_file_chooser_dialog_new(_("Open archive"), 
-																			 GTK_WINDOW(window),
-																			 GTK_FILE_CHOOSER_ACTION_OPEN,
-																			 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-																			 GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
+		                                     GTK_WINDOW(window),
+		                                     GTK_FILE_CHOOSER_ACTION_OPEN,
+		                                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+		                                     GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL);
 
 	gtk_file_chooser_set_select_multiple(GTK_FILE_CHOOSER(dialog), TRUE);
+
+	GSList *supported_mime_types = lsq_get_supported_mime_types(0);
+	GSList *_supported_mime_types = supported_mime_types;
+	
+	GtkFileFilter *filter_all = gtk_file_filter_new();
+	gtk_file_filter_set_name(filter_all, _("Archives"));
+	while(_supported_mime_types)
+	{
+		GtkFileFilter *filter = gtk_file_filter_new();
+		gtk_file_filter_add_mime_type(filter,
+		        lsq_archive_mime_get_name((LSQArchiveMime *)(_supported_mime_types->data)));
+
+		gtk_file_filter_set_name(filter, lsq_archive_mime_get_comment((LSQArchiveMime *)(_supported_mime_types->data)));
+		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter);
+
+		gtk_file_filter_add_mime_type(filter_all,
+		        lsq_archive_mime_get_name((LSQArchiveMime *)(_supported_mime_types->data)));
+		_supported_mime_types = g_slist_next(_supported_mime_types);
+	}
+	g_slist_free(supported_mime_types);
+
+	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(dialog), filter_all);
+	gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(dialog), filter_all);
+	
+
 	result = gtk_dialog_run (GTK_DIALOG (dialog) );
 	if(result == GTK_RESPONSE_CANCEL || result == GTK_RESPONSE_DELETE_EVENT)
 	{
@@ -731,13 +764,12 @@ cb_sq_main_extract_archive(GtkWidget *widget, gpointer userdata)
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 
 	LSQArchive        *lp_archive = NULL;
-	LSQArchiveSupport *lp_support = NULL;
 
 	GSList *filenames = sq_notebook_get_selected_items(SQ_NOTEBOOK(window->notebook));
 
-	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive, &lp_support);
+	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive);
 
-	dialog = sq_extract_archive_dialog_new(lp_support, lp_archive, g_slist_length(filenames));
+	dialog = sq_extract_archive_dialog_new(lp_archive, g_slist_length(filenames));
 	result = gtk_dialog_run (GTK_DIALOG (dialog) );
 	if(result == GTK_RESPONSE_OK)
 	{
@@ -748,7 +780,7 @@ cb_sq_main_extract_archive(GtkWidget *widget, gpointer userdata)
 			g_slist_free(filenames);
 			filenames = NULL;
 		}
-		if(lsq_archive_support_extract(lp_support, lp_archive, extract_archive_path, filenames))
+		if(!lsq_archive_extract(lp_archive, extract_archive_path, filenames))
 		{
 			GtkWidget *warning_dialog = gtk_message_dialog_new(GTK_WINDOW(window), 
 			                                                   GTK_DIALOG_DESTROY_WITH_PARENT, 
@@ -774,13 +806,12 @@ cb_sq_main_add_to_archive(GtkWidget *widget, gpointer userdata)
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 
 	LSQArchive        *lp_archive = NULL;
-	LSQArchiveSupport *lp_support = NULL;
 	GtkWidget         *dialog = NULL;
 	GSList            *filenames = NULL;
 	gint result;
-	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive, &lp_support);
+	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive);
 
-	dialog = sq_add_dialog_new(lp_support);
+	dialog = sq_add_dialog_new();
 
 	result = gtk_dialog_run (GTK_DIALOG(dialog));
 	if(result == GTK_RESPONSE_OK)
@@ -789,7 +820,7 @@ cb_sq_main_add_to_archive(GtkWidget *widget, gpointer userdata)
 		filenames = sq_add_dialog_get_filenames(SQ_ADD_DIALOG(dialog));
 		if(filenames)
 		{
-			if(lsq_archive_support_add(lp_support, lp_archive, filenames))
+			if(!lsq_archive_add(lp_archive, filenames))
 			{
 				GtkWidget *warning_dialog = gtk_message_dialog_new(GTK_WINDOW(window), 
 																													 GTK_DIALOG_DESTROY_WITH_PARENT, 
@@ -809,7 +840,6 @@ cb_sq_main_remove_from_archive(GtkWidget *widget, gpointer userdata)
 {
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 	LSQArchive        *lp_archive = NULL;
-	LSQArchiveSupport *lp_support = NULL;
 	GtkWidget *dialog = NULL;
 	gint result = 0;
 	GSList *filenames = sq_notebook_get_selected_items(SQ_NOTEBOOK(window->notebook));
@@ -821,9 +851,9 @@ cb_sq_main_remove_from_archive(GtkWidget *widget, gpointer userdata)
 		if(result == GTK_RESPONSE_YES)
 		{
 			gtk_widget_hide(dialog);
-			sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive, &lp_support);
+			sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive);
 			/* gtk_tree_view_set_model(sq_notebook_get_active_tree_view(SQ_NOTEBOOK(window->notebook)), NULL); */
-			if(lsq_archive_support_remove(lp_support, lp_archive, filenames))
+			if(!lsq_archive_remove(lp_archive, filenames))
 			{
 				GtkWidget *warning_dialog = gtk_message_dialog_new(GTK_WINDOW(window), 
 																													 GTK_DIALOG_DESTROY_WITH_PARENT, 
@@ -852,18 +882,26 @@ cb_sq_main_close_window(GtkWidget *widget, gpointer userdata)
 	gtk_widget_destroy(GTK_WIDGET(window));
 }
 
+static void 
+cb_sq_main_refresh_archive(GtkWidget *widget, gpointer userdata)
+{
+	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
+	SQArchiveStore *store = sq_notebook_get_active_store(SQ_NOTEBOOK(window->notebook));
+	LSQArchive *archive = sq_archive_store_get_archive(store);
+	lsq_archive_refresh(archive);
+}
+
 static void
 cb_sq_main_stop_archive(GtkWidget *widget, gpointer userdata)
 {
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 
 	LSQArchive        *lp_archive = NULL;
-	LSQArchiveSupport *lp_support = NULL;
 	GtkWidget         *dialog = NULL;
 	gint result = 0;
-	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive, &lp_support);
+	sq_notebook_get_active_archive(SQ_NOTEBOOK(window->notebook), &lp_archive);
 	
-	if(lsq_archive_support_can_stop(lp_support, lp_archive))
+	if(lsq_archive_can_stop(lp_archive))
 		lsq_archive_stop(lp_archive);
 	else
 	{
@@ -956,10 +994,15 @@ cb_sq_main_about(GtkWidget *widget, gpointer userdata)
 		_("Contributors:"),
 		"Peter de Ridder <peter@xfce.org>",
 		"",
-		_("Artwork:"),
-		_("The add and extract icons are based on the extract icon created by Andreas Nilsson"),
-		"",
 		_("Inspired by Xarchiver, written by Giuseppe Torelli"), NULL};
+	const gchar *artists[] = {
+		_("Application Icon:"),
+		"Stephan Arts <stephan@xfce.org>",
+		"",
+		_("Add / Extract icons:"),
+		_("Based on the original extract icon created by Andreas Nilsson"),
+		NULL
+	};
 	GtkWidget *about_dialog = gtk_about_dialog_new();
 
 	gtk_about_dialog_set_name((GtkAboutDialog *)about_dialog, PACKAGE_NAME);
@@ -971,10 +1014,15 @@ cb_sq_main_about(GtkWidget *widget, gpointer userdata)
 
 	gtk_about_dialog_set_authors((GtkAboutDialog *)about_dialog, authors);
 
+	/* Translator credits as shown in the about dialog: NAME <E-MAIL> YEAR */
 	gtk_about_dialog_set_translator_credits((GtkAboutDialog *)about_dialog, _("translator-credits"));
 
 	gtk_about_dialog_set_license((GtkAboutDialog *)about_dialog, xfce_get_license_text(XFCE_LICENSE_TEXT_GPL));
 
+	gtk_about_dialog_set_artists((GtkAboutDialog *)about_dialog, artists);
+
+	gtk_about_dialog_set_copyright((GtkAboutDialog *)about_dialog, "Copyright \302\251 2006-2007 Stephan Arts");
+
 	gtk_dialog_run(GTK_DIALOG(about_dialog));
 
 	gtk_widget_destroy(about_dialog);
@@ -985,23 +1033,26 @@ static void
 cb_sq_main_window_notebook_page_switched(SQNotebook *notebook, GtkNotebookPage *page, guint page_nr, gpointer data)
 {
 	LSQArchive *lp_archive;
-	LSQArchiveSupport *lp_support;
-	sq_notebook_page_get_archive(notebook, &lp_archive, &lp_support, page_nr);
+	sq_notebook_page_get_archive(notebook, &lp_archive, page_nr);
 	SQMainWindow *window = SQ_MAIN_WINDOW(data);
-	LSQArchiveStatus status = LSQ_ARCHIVESTATUS_IDLE;
 
-	if(lp_archive)
-		 status = lsq_archive_get_status(lp_archive);
+	gtk_window_set_title(GTK_WINDOW(window), g_strconcat(PACKAGE_NAME, " - ", lsq_archive_get_filename(lp_archive), NULL));
 
-	if(lp_archive && (status == LSQ_ARCHIVESTATUS_IDLE || status == LSQ_ARCHIVESTATUS_ERROR || status == LSQ_ARCHIVESTATUS_USERBREAK))
+	sq_main_window_new_action_menu(window, lp_archive);
+
+	guint context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(window->statusbar), "Window Statusbar");
+	const gchar *message = lsq_archive_get_status(lp_archive);
+	if(!message)
 	{
+		message = _("Done");
 		if(window->menu_bar)
 		{
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_add), TRUE);
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_extract), TRUE);
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_remove), TRUE);
+			sq_throbber_set_animated(SQ_THROBBER(window->throbber), FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_add, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_extract, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_remove, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, TRUE);
 		}
-
 		if(window->tool_bar)
 		{
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_add), TRUE);
@@ -1014,9 +1065,11 @@ cb_sq_main_window_notebook_page_switched(SQNotebook *notebook, GtkNotebookPage *
 	{
 		if(window->menu_bar)
 		{
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_add), FALSE);
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_extract), FALSE);
-			gtk_widget_set_sensitive(GTK_WIDGET(window->menubar.menu_item_remove), FALSE);
+			sq_throbber_set_animated(SQ_THROBBER(window->throbber), TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_add, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_extract, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_remove, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, FALSE);
 		}
 
 		if(window->tool_bar)
@@ -1026,14 +1079,9 @@ cb_sq_main_window_notebook_page_switched(SQNotebook *notebook, GtkNotebookPage *
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_remove), FALSE);
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_stop), TRUE);
 		}
+
 	}
-
-	gtk_window_set_title(GTK_WINDOW(window), g_strconcat(PACKAGE_NAME, " - ", lsq_archive_get_filename(lp_archive), NULL));
-
-	sq_main_window_new_action_menu(window, lp_support, lp_archive);
-
-	guint context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(window->statusbar), "Window Statusbar");
-	gtk_statusbar_push(GTK_STATUSBAR(window->statusbar), context_id, lsq_archive_get_status_msg(lp_archive));
+	gtk_statusbar_push(GTK_STATUSBAR(window->statusbar), context_id, message);
 }
 
 static void
@@ -1051,6 +1099,7 @@ cb_sq_main_window_notebook_page_removed(SQNotebook *notebook, gpointer data)
 			gtk_widget_set_sensitive(window->menubar.menu_item_add, FALSE);
 			gtk_widget_set_sensitive(window->menubar.menu_item_extract, FALSE);
 			gtk_widget_set_sensitive(window->menubar.menu_item_remove, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, FALSE);
 		}
 
 		if(window->tool_bar)
@@ -1062,15 +1111,16 @@ cb_sq_main_window_notebook_page_removed(SQNotebook *notebook, gpointer data)
 		}
 
 		gtk_window_set_title(GTK_WINDOW(window), PACKAGE_STRING);
+		guint context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(window->statusbar), "Window Statusbar");
+		gtk_statusbar_push(GTK_STATUSBAR(window->statusbar), context_id, _("Done"));
 	}
 }
 
 static void
-cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, gchar *path, gpointer data)
+cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, LSQArchiveIter *iter, gpointer data)
 {
 	GtkWindow *window = GTK_WINDOW(data);
 	LSQArchive *lp_archive = NULL;
-	LSQArchiveSupport *lp_support = NULL;
 	gchar *extract_archive_path = NULL;
 	GtkWidget *label = gtk_label_new(_("Which action do you want to perform on the selected file(s)?"));
 	GtkWidget *dialog = gtk_dialog_new_with_buttons("",window,GTK_DIALOG_DESTROY_WITH_PARENT, _("Open"), GTK_RESPONSE_OK, _("Extract"), GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL);
@@ -1080,12 +1130,12 @@ cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, gchar *path, gpo
 	gint result = gtk_dialog_run(GTK_DIALOG(dialog));
 	gtk_widget_hide(dialog);
 
-	GSList *filenames = g_slist_prepend(NULL, path);
+	GSList *files = g_slist_prepend(NULL, iter);
 	switch(result)
 	{
 		case GTK_RESPONSE_OK: /* VIEW */
-			sq_notebook_get_active_archive(SQ_NOTEBOOK(notebook), &lp_archive, &lp_support);
-			if(lsq_archive_support_view(lp_support, lp_archive, filenames))
+			sq_notebook_get_active_archive(SQ_NOTEBOOK(notebook), &lp_archive);
+			if(lsq_archive_view(lp_archive, files))
 			{
 				GtkWidget *warning_dialog = gtk_message_dialog_new(window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_WARNING, GTK_BUTTONS_CLOSE, _("Squeeze cannot view this file.\nthe application to support this is missing."));
 				if(warning_dialog)
@@ -1096,8 +1146,8 @@ cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, gchar *path, gpo
 			}
 			break;
 		case GTK_RESPONSE_ACCEPT: /* EXTRACT */
-			sq_notebook_get_active_archive(SQ_NOTEBOOK(notebook), &lp_archive, &lp_support);
-			extr_dialog = sq_extract_archive_dialog_new(lp_support, lp_archive, 1);
+			sq_notebook_get_active_archive(SQ_NOTEBOOK(notebook), &lp_archive);
+			extr_dialog = sq_extract_archive_dialog_new(lp_archive, 1);
 			result = gtk_dialog_run (GTK_DIALOG (extr_dialog) );
 			if(result == GTK_RESPONSE_OK)
 			{
@@ -1105,16 +1155,16 @@ cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, gchar *path, gpo
 				extract_archive_path = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(extr_dialog));
 				if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(SQ_EXTRACT_ARCHIVE_DIALOG(extr_dialog)->all_files_radio)))
 				{
-					g_slist_free(filenames);
-					filenames = NULL;
+					g_slist_free(files);
+					files = NULL;
 				}
-				if(lsq_archive_support_extract(lp_support, lp_archive, extract_archive_path, filenames))
+				if(lsq_archive_extract(lp_archive, extract_archive_path, files))
 				{
 					GtkWidget *warning_dialog = gtk_message_dialog_new(GTK_WINDOW(window), 
-																														 GTK_DIALOG_DESTROY_WITH_PARENT, 
-																														 GTK_MESSAGE_WARNING,
-																														 GTK_BUTTONS_CLOSE,
-																														 _("Squeeze cannot extract this archive type,\nthe application to support this is missing."));
+																	 GTK_DIALOG_DESTROY_WITH_PARENT, 
+																	 GTK_MESSAGE_WARNING,
+																	 GTK_BUTTONS_CLOSE,
+																	 _("Squeeze cannot extract this archive type,\nthe application to support this is missing."));
 					gtk_dialog_run (GTK_DIALOG (warning_dialog) );
 					gtk_widget_destroy(warning_dialog);
 
@@ -1128,7 +1178,7 @@ cb_sq_main_window_notebook_file_activated(SQNotebook *notebook, gchar *path, gpo
 		case GTK_RESPONSE_CANCEL: /* CANCEL */
 			break;
 	}
-	g_slist_free(filenames);
+	g_slist_free(files);
 	gtk_widget_destroy(dialog);
 }
 
@@ -1136,17 +1186,17 @@ gint
 sq_main_window_open_archive(SQMainWindow *window, gchar *path, gint replace)
 {
 	LSQArchive *archive = NULL;
-	LSQArchiveSupport *support = NULL;
 
 	if(!lsq_open_archive(path, &archive))
 	{
-		support = lsq_get_support_for_mime(archive->mime_info);
 		if(replace < 0)
-			sq_notebook_add_archive(SQ_NOTEBOOK(window->notebook), archive, support, FALSE);
+			sq_notebook_add_archive(SQ_NOTEBOOK(window->notebook), archive, FALSE);
 		else
-			sq_notebook_page_set_archive(SQ_NOTEBOOK(window->notebook), archive, support, replace);
+			sq_notebook_page_set_archive(SQ_NOTEBOOK(window->notebook), archive, replace);
 		gtk_widget_set_sensitive(window->menubar.menu_item_close, TRUE);
+
 		/*gtk_widget_set_sensitive(window->menubar.menu_item_properties, TRUE);*/
+		g_signal_connect(G_OBJECT(archive), "command-terminated", G_CALLBACK(cb_sq_main_window_archive_command_terminated), window);
 		return 0;
 	}
 	else
@@ -1207,22 +1257,35 @@ sq_main_window_set_navigation(SQMainWindow *window)
 }
 
 static void
-cb_sq_main_window_notebook_status_changed(SQNotebook *notebook, LSQArchive *archive, gpointer userdata)
+cb_sq_main_window_archive_command_terminated(LSQArchive *archive, GError *error, gpointer userdata)
+{
+	SQMainWindow *window = userdata;
+
+	if(error)
+	{
+		GtkWidget *error_dialog = gtk_message_dialog_new(GTK_WINDOW(window), GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, error->message);
+		gtk_dialog_run(GTK_DIALOG(error_dialog));
+		gtk_widget_destroy(error_dialog);
+	}
+}
+
+static void
+cb_sq_main_window_notebook_state_changed(SQNotebook *notebook, LSQArchive *archive, gpointer userdata)
 {
 	SQMainWindow *window = SQ_MAIN_WINDOW(userdata);
 
-	LSQArchiveStatus status = lsq_archive_get_status(archive);
-
-	if((status == LSQ_ARCHIVESTATUS_IDLE) || (status == LSQ_ARCHIVESTATUS_USERBREAK) || (status == LSQ_ARCHIVESTATUS_ERROR))
+	guint context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(window->statusbar), "Window Statusbar");
+	const gchar *message = lsq_archive_get_status(archive);
+	if(!message)
 	{
+		sq_throbber_set_animated(SQ_THROBBER(window->throbber), FALSE);
+		message = _("Done");
 		if(window->menu_bar)
 		{
-			gtk_widget_set_sensitive(window->menubar.menu_item_close, TRUE);
-			/*gtk_widget_set_sensitive(window->menubar.menu_item_properties, TRUE);*/
-
 			gtk_widget_set_sensitive(window->menubar.menu_item_add, TRUE);
 			gtk_widget_set_sensitive(window->menubar.menu_item_extract, TRUE);
 			gtk_widget_set_sensitive(window->menubar.menu_item_remove, TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, TRUE);
 		}
 
 		if(window->tool_bar)
@@ -1230,10 +1293,31 @@ cb_sq_main_window_notebook_status_changed(SQNotebook *notebook, LSQArchive *arch
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_add), TRUE);
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_extract), TRUE);
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_remove), TRUE);
+
 			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_stop), FALSE);
 		}
 	}
+	else
+	{
 
-	guint context_id = gtk_statusbar_get_context_id(GTK_STATUSBAR(window->statusbar), "Window Statusbar");
-	gtk_statusbar_push(GTK_STATUSBAR(window->statusbar), context_id, lsq_archive_get_status_msg(archive));
+		if(window->menu_bar)
+		{
+			sq_throbber_set_animated(SQ_THROBBER(window->throbber), TRUE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_add, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_extract, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_remove, FALSE);
+			gtk_widget_set_sensitive(window->menubar.menu_item_refresh, FALSE);
+		}
+
+		if(window->tool_bar)
+		{
+			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_add), FALSE);
+			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_extract), FALSE);
+			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_remove), FALSE);
+
+			gtk_widget_set_sensitive(GTK_WIDGET(window->toolbar.tool_item_stop), TRUE);
+		}
+	}
+
+	gtk_statusbar_push(GTK_STATUSBAR(window->statusbar), context_id, message);
 }
