@@ -1,6 +1,4 @@
 /*
- *  Copyright (c) 2006 Stephan Arts <stephan@xfce.org>
- *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
@@ -28,6 +26,7 @@
 #include "tool_bar.h"
 #include "path_bar.h"
 #include "notebook.h"
+#include "throbber.h"
 
 static void
 sq_notebook_class_init(SQNotebookClass *archive_class);
@@ -53,12 +52,14 @@ sq_notebook_get_tree_view(SQNotebook *notebook, gint page_nr);
 static void
 cb_notebook_close_archive(GtkButton *button, GtkWidget *child);
 
-static void
-cb_notebook_archive_status_changed(LSQArchive *archive, SQNotebook *notebook);
 static void
 cb_notebook_archive_refreshed(LSQArchive *archive, GtkTreeView *tree_view);
 static void
-cb_notebook_file_activated(SQArchiveStore *, gchar *, SQNotebook *);
+cb_notebook_archive_state_changed(LSQArchive *archive, SQNotebook *notebook);
+static void
+cb_notebook_tab_archive_state_changed(LSQArchive *archive, GtkContainer *widget);
+static void
+cb_notebook_file_activated(SQArchiveStore *, LSQArchiveIter *, SQNotebook *);
 
 static void
 cb_sq_notebook_page_switched(SQNotebook *notebook, GtkNotebookPage *, guint page_nr, gpointer data);
@@ -70,6 +71,7 @@ cb_sq_notebook_notify_proxy(GObject *obj, GParamSpec *pspec, gpointer user_data)
 
 enum {
 	SQ_NOTEBOOK_MULTI_TAB = 1,
+	SQ_NOTEBOOK_STORE_SHOW_FULL_PATH,
 	SQ_NOTEBOOK_STORE_SHOW_ICONS,
 	SQ_NOTEBOOK_STORE_SORT_FOLDERS_FIRST,
 	SQ_NOTEBOOK_STORE_SORT_CASE_SENSITIVE,
@@ -82,7 +84,7 @@ enum
 	SQ_NOTEBOOK_SIGNAL_PAGE_UP,
 	SQ_NOTEBOOK_SIGNAL_PAGE_DOWN,
 	SQ_NOTEBOOK_SIGNAL_FILE_ACTIVATED,
-	SQ_NOTEBOOK_SIGNAL_ACTIVE_ARCHIVE_STATUS_CHANGED,
+	SQ_NOTEBOOK_SIGNAL_STATE_CHANGED, /* is emitted when the state of the active archive changed */
 	SQ_NOTEBOOK_SIGNAL_COUNT
 };
 
@@ -160,7 +162,7 @@ sq_notebook_class_init(SQNotebookClass *notebook_class)
 			g_cclosure_marshal_VOID__POINTER,
 			G_TYPE_NONE, 1, G_TYPE_STRING, NULL);
 
-	sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_ACTIVE_ARCHIVE_STATUS_CHANGED] = g_signal_new("active-archive-status-changed",
+	sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_STATE_CHANGED] = g_signal_new("archive-state-changed",
 			G_TYPE_FROM_CLASS(notebook_class),
 			G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION, 0,
 			NULL, NULL,
@@ -173,6 +175,13 @@ sq_notebook_class_init(SQNotebookClass *notebook_class)
 		TRUE,
 		G_PARAM_READWRITE); g_object_class_install_property(object_class, SQ_NOTEBOOK_MULTI_TAB, pspec); 
 
+	pspec = g_param_spec_boolean("show-full-path",
+		_("Show full path"),
+		_("Show the full path strings for each entry"),
+		FALSE,
+		G_PARAM_READWRITE);
+	g_object_class_install_property(object_class, SQ_NOTEBOOK_STORE_SHOW_FULL_PATH, pspec);
+
 	pspec = g_param_spec_boolean("show-icons",
 		_("Show mime icons"),
 		_("Show the mime type icons for each entry"),
@@ -215,6 +224,7 @@ sq_notebook_init(SQNotebook *notebook)
 
 	notebook->current_page_fix = 0;
 	notebook->props._rules_hint = sq_settings_read_bool_entry(notebook->settings, "RulesHint", FALSE);
+	notebook->props._show_full_path = sq_settings_read_bool_entry(notebook->settings, "ShowFullPath", FALSE);
 	notebook->props._show_icons = sq_settings_read_bool_entry(notebook->settings, "ShowIcons", TRUE);
 	notebook->props._sort_folders_first = sq_settings_read_bool_entry(notebook->settings, "SortFoldersFirst", TRUE);
 	notebook->props._sort_case_sensitive = sq_settings_read_bool_entry(notebook->settings, "SortCaseSensitive", TRUE);
@@ -238,6 +248,7 @@ sq_notebook_dispose(GObject *object)
 	if(sq_notebook->settings)
 	{
 		sq_settings_write_bool_entry(sq_notebook->settings, "RulesHint", sq_notebook->props._rules_hint);
+		sq_settings_write_bool_entry(sq_notebook->settings, "ShowFullPath", sq_notebook->props._show_full_path);
 		sq_settings_write_bool_entry(sq_notebook->settings, "ShowIcons", sq_notebook->props._show_icons);
 		sq_settings_write_bool_entry(sq_notebook->settings, "SortFoldersFirst", sq_notebook->props._sort_folders_first);
 		sq_settings_write_bool_entry(sq_notebook->settings, "SortCaseSensitive", sq_notebook->props._sort_case_sensitive);
@@ -299,6 +310,14 @@ sq_notebook_set_property(GObject *object, guint prop_id, const GValue *value, GP
 		case SQ_NOTEBOOK_MULTI_TAB:
 			SQ_NOTEBOOK(object)->multi_tab = g_value_get_boolean(value);		
 			break;
+		case SQ_NOTEBOOK_STORE_SHOW_FULL_PATH:
+		{
+			SQArchiveStore *store = sq_notebook_get_store(SQ_NOTEBOOK(object), SQ_NOTEBOOK(object)->current_page_fix);
+			if(store)
+				sq_archive_store_set_show_full_path(store, g_value_get_boolean(value));
+			SQ_NOTEBOOK(object)->props._show_full_path = g_value_get_boolean(value);
+			break;
+		}
 		case SQ_NOTEBOOK_STORE_SHOW_ICONS:
 		{
 			SQArchiveStore *store = sq_notebook_get_store(SQ_NOTEBOOK(object), SQ_NOTEBOOK(object)->current_page_fix);
@@ -342,6 +361,15 @@ sq_notebook_get_property(GObject *object, guint prop_id, GValue *value, GParamSp
 		case SQ_NOTEBOOK_MULTI_TAB:
 			g_value_set_boolean(value, SQ_NOTEBOOK(object)->multi_tab);
 			break;
+		case SQ_NOTEBOOK_STORE_SHOW_FULL_PATH:
+		{
+			SQArchiveStore *store = sq_notebook_get_store(SQ_NOTEBOOK(object), SQ_NOTEBOOK(object)->current_page_fix);
+			if(store)
+				g_value_set_boolean(value, sq_archive_store_get_show_full_path(store));
+			else
+				g_value_set_boolean(value, SQ_NOTEBOOK(object)->props._show_full_path);
+			break;
+		}
 		case SQ_NOTEBOOK_STORE_SHOW_ICONS:
 		{
 			SQArchiveStore *store = sq_notebook_get_store(SQ_NOTEBOOK(object), SQ_NOTEBOOK(object)->current_page_fix);
@@ -465,11 +493,19 @@ sq_notebook_set_navigation_bar(SQNotebook *notebook, SQNavigationBar *bar)
 }
 
 void
-sq_notebook_add_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchiveSupport *support, gboolean new_archive)
+sq_notebook_add_archive(SQNotebook *notebook, LSQArchive *archive, gboolean new_archive)
 {
 	GtkWidget *lbl_hbox = gtk_hbox_new(FALSE, 0);
 	GtkWidget *label = gtk_label_new(lsq_archive_get_filename(archive));
-	GtkWidget *archive_image = gtk_image_new_from_icon_name(thunar_vfs_mime_info_lookup_icon_name(archive->mime_info, notebook->icon_theme), GTK_ICON_SIZE_MENU);
+	GtkWidget *archive_image = gtk_image_new_from_icon_name("unknown", GTK_ICON_SIZE_MENU);
+	GtkWidget *throbber = sq_throbber_new();
+	GtkWidget *alignment = gtk_alignment_new(0.5,0.5,1,1);
+	
+	gtk_alignment_set_padding(GTK_ALIGNMENT(alignment), 4, 0, 0, 0);
+
+	gtk_container_add(GTK_CONTAINER(alignment), throbber);
+
+	/*thunar_vfs_mime_info_lookup_icon_name(lsq_archive_get_mimetype(archive), notebook->icon_theme), GTK_ICON_SIZE_MENU);*/
 	GtkWidget *close_button = gtk_button_new();
 	GtkWidget *close_image = gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
 	GtkWidget *scroll_window = gtk_scrolled_window_new(NULL, NULL);
@@ -479,6 +515,8 @@ sq_notebook_add_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchiveSup
 	gtk_button_set_image(GTK_BUTTON(close_button), close_image);
 	gtk_button_set_relief(GTK_BUTTON(close_button), GTK_RELIEF_NONE);
 
+	gtk_widget_set_size_request(lbl_hbox, -1, 22);
+
 	gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_MIDDLE);
 	gtk_label_set_max_width_chars(GTK_LABEL(label), 20);
 	gtk_tooltips_set_tip(notebook->tool_tips, label, lsq_archive_get_filename(archive), NULL);
@@ -491,25 +529,27 @@ sq_notebook_add_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchiveSup
 	gtk_tree_selection_set_mode(selection, GTK_SELECTION_MULTIPLE);
 
 	GtkTreeModel *tree_model = sq_archive_store_new(archive, notebook->props._show_icons, notebook->props._up_dir, notebook->icon_theme);
+	sq_archive_store_set_show_full_path(SQ_ARCHIVE_STORE(tree_model), notebook->props._show_full_path);
 	sq_archive_store_set_sort_folders_first(SQ_ARCHIVE_STORE(tree_model), notebook->props._sort_folders_first);
 	sq_archive_store_set_sort_case_sensitive(SQ_ARCHIVE_STORE(tree_model), notebook->props._sort_case_sensitive);
 	g_signal_connect(G_OBJECT(tree_model), "notify", G_CALLBACK(cb_sq_notebook_notify_proxy), notebook);
 
 	gtk_box_pack_start(GTK_BOX(lbl_hbox), archive_image, FALSE, FALSE, 3);
+	gtk_box_pack_start(GTK_BOX(lbl_hbox), alignment, FALSE, FALSE, 3);
 	gtk_box_pack_start(GTK_BOX(lbl_hbox), label, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(lbl_hbox), close_button, FALSE, FALSE, 0);
 	gtk_widget_show_all(lbl_hbox);
 	gtk_widget_show_all(tree_view);
 	gtk_widget_show(scroll_window);
 
-	g_signal_connect(G_OBJECT(archive), "lsq_status_changed", G_CALLBACK(cb_notebook_archive_status_changed), notebook);
-	g_signal_connect(G_OBJECT(archive), "lsq_refreshed", G_CALLBACK(cb_notebook_archive_refreshed), tree_view);
+	g_signal_connect(G_OBJECT(archive), "refreshed", G_CALLBACK(cb_notebook_archive_refreshed), tree_view);
+	g_signal_connect(G_OBJECT(archive), "state-changed", G_CALLBACK(cb_notebook_archive_state_changed), notebook);
+	g_signal_connect(G_OBJECT(archive), "state-changed", G_CALLBACK(cb_notebook_tab_archive_state_changed), lbl_hbox);
 
 	g_signal_connect(G_OBJECT(close_button), "clicked", G_CALLBACK(cb_notebook_close_archive), scroll_window);
-	g_signal_connect(G_OBJECT(tree_model), "sq_file_activated", G_CALLBACK(cb_notebook_file_activated), notebook);
+	g_signal_connect(G_OBJECT(tree_model), "file-activated", G_CALLBACK(cb_notebook_file_activated), notebook);
 
 
-	sq_archive_store_set_support(SQ_ARCHIVE_STORE(tree_model), support);
 	sq_archive_store_connect_treeview(SQ_ARCHIVE_STORE(tree_model), GTK_TREE_VIEW(tree_view));
 
 	gtk_tree_view_set_model(GTK_TREE_VIEW(tree_view), tree_model);
@@ -531,66 +571,11 @@ sq_notebook_add_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchiveSup
 
 	if(new_archive == FALSE)
 	{
-		lsq_archive_support_refresh(support, archive);
+		lsq_archive_refresh(archive);
 	}
 
 }
 
-void
-cb_notebook_archive_status_changed(LSQArchive *archive, SQNotebook *notebook)
-{
-	GtkWidget *dialog = NULL;
-
-#ifdef DEBUG
-	g_debug("NOTEBOOK: Archive status changed");
-#endif /* DEBUG */
-	if(lsq_archive_get_status(archive) == LSQ_ARCHIVESTATUS_ERROR)
-	{
-		switch(lsq_archive_get_old_status(archive))
-		{
-			case LSQ_ARCHIVESTATUS_REFRESH:
-				dialog = gtk_message_dialog_new(NULL, 
-				                                0, 
-																				GTK_MESSAGE_ERROR, 
-																				GTK_BUTTONS_OK, 
-																				_("Failed to open archive '%s'."), 
-																				lsq_archive_get_filename(archive));
-				break;
-			case LSQ_ARCHIVESTATUS_EXTRACT:
-			case LSQ_ARCHIVESTATUS_PREPARE_VIEW:
-				dialog = gtk_message_dialog_new(NULL, 
-				                                0, 
-																				GTK_MESSAGE_ERROR, 
-																				GTK_BUTTONS_OK, 
-																				_("Failed to extract contents of archive '%s'."), 
-																				lsq_archive_get_filename(archive));
-				break;
-			default:
-				break;
-		}
-		if(dialog)
-		{
-			gtk_dialog_run((GtkDialog *)dialog);
-			gtk_widget_destroy(dialog);
-		}
-	}
-	if(lsq_archive_get_status(archive) == LSQ_ARCHIVESTATUS_IDLE)
-	{
-		switch(lsq_archive_get_old_status(archive))
-		{
-			case LSQ_ARCHIVESTATUS_ADD:
-				if(lsq_archive_support_refresh(archive->support, archive))
-				{
-					/* FIXME: show warning dialog */
-				}
-				break;
-			default:break;
-		}
-	}
-	if(sq_notebook_is_active_archive(notebook, archive))
-		g_signal_emit(G_OBJECT(notebook), sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_ACTIVE_ARCHIVE_STATUS_CHANGED], 0, archive, NULL);
-}
-
 static void
 cb_notebook_close_archive(GtkButton *button, GtkWidget *child)
 {
@@ -602,7 +587,9 @@ cb_notebook_close_archive(GtkButton *button, GtkWidget *child)
 	LSQArchive *archive = sq_archive_store_get_archive(SQ_ARCHIVE_STORE(archive_store));
 
 	if(archive)
+	{
 		g_signal_handlers_disconnect_by_func(archive, cb_notebook_archive_refreshed, treeview);
+	}
 	if(SQ_NOTEBOOK(notebook)->navigation_bar)
 		sq_navigation_bar_set_store(((SQNotebook *)notebook)->navigation_bar, NULL);
 	g_object_unref(archive_store);
@@ -652,6 +639,33 @@ cb_notebook_archive_refreshed(LSQArchive *archive, GtkTreeView *treeview)
 	sq_notebook_treeview_reset_columns(archive, treeview);
 }
 
+static void
+cb_notebook_archive_state_changed(LSQArchive *archive, SQNotebook *notebook)
+{
+	if(sq_notebook_is_active_archive(notebook, archive))
+		g_signal_emit(G_OBJECT(notebook), sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_STATE_CHANGED], 0, archive, NULL);
+}
+
+static void
+cb_notebook_tab_archive_state_changed(LSQArchive *archive, GtkContainer *widget)
+{
+	GList *children = gtk_container_get_children(widget);
+	if(lsq_archive_get_status(archive))
+	{
+		gtk_widget_hide(GTK_WIDGET(children->data));
+		sq_throbber_set_animated(SQ_THROBBER(gtk_bin_get_child(GTK_BIN(children->next->data))), TRUE);
+		gtk_widget_show(GTK_WIDGET(children->next->data));
+	}
+	else
+	{
+		gtk_widget_show(GTK_WIDGET(children->data));
+		sq_throbber_set_animated(SQ_THROBBER(gtk_bin_get_child(GTK_BIN(children->next->data))), FALSE);
+		gtk_widget_hide(GTK_WIDGET(children->next->data));
+	}
+
+	g_list_free(children);
+}
+
 static void
 sq_notebook_treeview_reset_columns(LSQArchive *archive, GtkTreeView *treeview)
 {
@@ -674,36 +688,36 @@ sq_notebook_treeview_reset_columns(LSQArchive *archive, GtkTreeView *treeview)
 	renderer = gtk_cell_renderer_pixbuf_new();
 	g_object_set(G_OBJECT(renderer), "stock-size", GTK_ICON_SIZE_SMALL_TOOLBAR, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
-	gtk_tree_view_column_set_attributes(column, renderer, "icon-name", 0, NULL);
+	gtk_tree_view_column_set_attributes(column, renderer, "icon-name", SQ_ARCHIVE_STORE_EXTRA_PROP_ICON, NULL);
 
 	renderer = gtk_cell_renderer_text_new();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_attributes(column, renderer, "text", LSQ_ARCHIVE_PROP_FILENAME + 1, NULL);
+	gtk_tree_view_column_set_attributes(column, renderer, "text", LSQ_ARCHIVE_PROP_FILENAME + SQ_ARCHIVE_STORE_EXTRA_PROP_COUNT, NULL);
 
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_column_set_sizing(column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
-	gtk_tree_view_column_set_sort_column_id(column, LSQ_ARCHIVE_PROP_FILENAME + 1);
+	gtk_tree_view_column_set_sort_column_id(column, LSQ_ARCHIVE_PROP_FILENAME + SQ_ARCHIVE_STORE_EXTRA_PROP_COUNT);
 	gtk_tree_view_column_set_title(column, lsq_archive_get_entry_property_name(archive, LSQ_ARCHIVE_PROP_FILENAME));
 	gtk_tree_view_append_column(treeview, column);
 
 	if(!show_only_filenames)
 	{
-		for(x = LSQ_ARCHIVE_PROP_USER; x < lsq_archive_n_property(archive); ++x)
+		for(x = LSQ_ARCHIVE_PROP_USER; x < lsq_archive_n_entry_properties(archive); ++x)
 		{
 			switch(lsq_archive_get_entry_property_type(archive, x))
 			{
 				case(G_TYPE_STRING):
 				case(G_TYPE_UINT64):
 					renderer = gtk_cell_renderer_text_new();
-					column = gtk_tree_view_column_new_with_attributes(lsq_archive_get_entry_property_name(archive, x), renderer, "text", x+1, NULL);
+					column = gtk_tree_view_column_new_with_attributes(lsq_archive_get_entry_property_name(archive, x), renderer, "text", x+SQ_ARCHIVE_STORE_EXTRA_PROP_COUNT, NULL);
 					break;
 			}
 			gtk_tree_view_column_set_resizable(column, TRUE);
-			gtk_tree_view_column_set_sort_column_id(column, x+1);
+			gtk_tree_view_column_set_sort_column_id(column, x+SQ_ARCHIVE_STORE_EXTRA_PROP_COUNT);
 			gtk_tree_view_append_column(treeview, column);
 		}
 	}
-	gtk_tree_view_set_search_column(treeview, 1);
+	gtk_tree_view_set_search_column(treeview, LSQ_ARCHIVE_PROP_FILENAME + SQ_ARCHIVE_STORE_EXTRA_PROP_COUNT);
 }
 
 void
@@ -742,11 +756,9 @@ cb_sq_notebook_page_removed(SQNotebook *notebook, gpointer data)
 }
 
 static void
-cb_notebook_file_activated(SQArchiveStore *store, gchar *filename, SQNotebook *notebook)
+cb_notebook_file_activated(SQArchiveStore *store, LSQArchiveIter *iter, SQNotebook *notebook)
 {
-	gchar *pwd = sq_archive_store_get_pwd(store);
-	gchar *path = g_strconcat(pwd, filename, NULL);
-	g_signal_emit(G_OBJECT(notebook), sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_FILE_ACTIVATED], 0, path, NULL);
+	g_signal_emit(G_OBJECT(notebook), sq_notebook_signals[SQ_NOTEBOOK_SIGNAL_FILE_ACTIVATED], 0, iter, NULL);
 }
 
 gboolean
@@ -762,11 +774,11 @@ sq_notebook_is_active_archive(SQNotebook *notebook, LSQArchive *archive)
 }
 
 void
-sq_notebook_get_active_archive(SQNotebook *notebook, LSQArchive **lp_archive, LSQArchiveSupport **lp_support)
+sq_notebook_get_active_archive(SQNotebook *notebook, LSQArchive **lp_archive)
 {
 	gint n = gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook));
 		
-	sq_notebook_page_get_archive(notebook, lp_archive, lp_support, n);
+	sq_notebook_page_get_archive(notebook, lp_archive, n);
 }
 
 GtkWidget *
@@ -778,7 +790,7 @@ sq_notebook_get_active_child(SQNotebook *notebook)
 }
 
 void
-sq_notebook_page_set_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchiveSupport *support, gint n)
+sq_notebook_page_set_archive(SQNotebook *notebook, LSQArchive *archive, gint n)
 {
 	if(gtk_notebook_get_n_pages(GTK_NOTEBOOK(notebook)))
 	{
@@ -787,12 +799,10 @@ sq_notebook_page_set_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchi
 		GtkTreeModel *store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 
 		sq_archive_store_set_archive(SQ_ARCHIVE_STORE(store), archive);
-		sq_archive_store_set_support(SQ_ARCHIVE_STORE(store), support);
 
-		g_signal_connect(G_OBJECT(archive), "lsq_status_changed", G_CALLBACK(cb_notebook_archive_status_changed), notebook);
-		g_signal_connect(G_OBJECT(archive), "lsq_refreshed", G_CALLBACK(cb_notebook_archive_refreshed), treeview);
+		g_signal_connect(G_OBJECT(archive), "refreshed", G_CALLBACK(cb_notebook_archive_refreshed), treeview);
 
-		if(lsq_archive_support_refresh(support, archive))
+		if(lsq_archive_refresh(archive))
 		{
 			/* FIXME: show warning dialog */
 		}
@@ -800,7 +810,7 @@ sq_notebook_page_set_archive(SQNotebook *notebook, LSQArchive *archive, LSQArchi
 		gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), store);
 	}
 	else
-		sq_notebook_add_archive(SQ_NOTEBOOK(notebook), archive, support, FALSE);
+		sq_notebook_add_archive(SQ_NOTEBOOK(notebook), archive, FALSE);
 }
 
 GSList *
@@ -814,36 +824,32 @@ sq_notebook_get_selected_items(SQNotebook *notebook)
 
 	GtkWidget *treeview = gtk_bin_get_child(GTK_BIN(scrolledwindow));
 	GtkTreeModel *store = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-	gchar *pwd = sq_archive_store_get_pwd(SQ_ARCHIVE_STORE(store));
 	GtkTreeSelection *selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(treeview));
 	GList *rows = gtk_tree_selection_get_selected_rows(selection, &store);
 	GList *_rows = rows;
 	while(_rows)
 	{
 		gtk_tree_model_get_iter(store, &iter, _rows->data);
-		gtk_tree_model_get_value(store, &iter, 1, &value);
+		LSQArchiveIter *entry = sq_archive_store_get_archive_iter(SQ_ARCHIVE_STORE(store), &iter);
 
-		filenames = g_slist_prepend(filenames, g_strconcat(pwd, g_value_get_string(&value), NULL));
+		lsq_archive_iter_ref(entry);
+		filenames = g_slist_prepend(filenames, entry);
 
-		g_value_unset((GValue*)&value);
 		_rows = _rows->next;
 	}
 	g_list_free(rows);
-	g_free(pwd);
 	
 	return filenames;
 }
-
+		
 
 void
-sq_notebook_page_get_archive(SQNotebook *notebook, LSQArchive **lp_archive, LSQArchiveSupport **lp_support, gint n)
+sq_notebook_page_get_archive(SQNotebook *notebook, LSQArchive **lp_archive, gint n)
 {
 	SQArchiveStore *store = sq_notebook_get_store(notebook, n);
 		
 	if(lp_archive)
 		(*lp_archive) = sq_archive_store_get_archive(store);
-	if(lp_support)
-		(*lp_support) = sq_archive_store_get_support(store);
 }
 
 static void
@@ -858,7 +864,7 @@ cb_sq_notebook_notify_proxy(GObject *obj, GParamSpec *pspec, gpointer user_data)
 
 		sq_notebook_treeview_reset_columns(sq_archive_store_get_archive(store), treeview);
 	}
-	if(strcmp(g_param_spec_get_name(pspec), "sort-folders-first") == 0 || strcmp(g_param_spec_get_name(pspec), "sort-case-sensitive") == 0)
+	if(strcmp(g_param_spec_get_name(pspec), "show-full-path") == 0 || strcmp(g_param_spec_get_name(pspec), "sort-folders-first") == 0 || strcmp(g_param_spec_get_name(pspec), "sort-case-sensitive") == 0)
 	{
 		g_object_notify(user_data, g_param_spec_get_name(pspec));
 	}
